@@ -10,22 +10,24 @@ use warnings;
 use warnings::register;
 
 use vars qw($VERSION $DATE $FILE );
-$VERSION = '0.02';
-$DATE = '2003/06/15';
+$VERSION = '0.03';
+$DATE = '2003/06/16';
 $FILE = __FILE__;
 
 use vars qw(%INVENTORY);
 %INVENTORY = (
-    'lib/Docs/Site_SVD/Test_Tech.pm' => [qw(0.02 2003/06/15), 'revised 0.01'],
-    'MANIFEST' => [qw(0.02 2003/06/15), 'generated, replaces 0.01'],
-    'Makefile.PL' => [qw(0.02 2003/06/15), 'generated, replaces 0.01'],
-    'README' => [qw(0.02 2003/06/15), 'generated, replaces 0.01'],
-    'lib/Test/Tech.pm' => [qw(1.04 2003/06/15), 'revised 1.03'],
-    't/Test/Tech/tech.t' => [qw(0.03 2003/06/15), 'revised 0.02'],
+    'lib/Docs/Site_SVD/Test_Tech.pm' => [qw(0.03 2003/06/16), 'revised 0.02'],
+    'MANIFEST' => [qw(0.03 2003/06/16), 'generated, replaces 0.02'],
+    'Makefile.PL' => [qw(0.03 2003/06/16), 'generated, replaces 0.02'],
+    'README' => [qw(0.03 2003/06/16), 'generated, replaces 0.02'],
+    'lib/Test/Tech.pm' => [qw(1.05 2003/06/16), 'revised 1.04'],
+    't/Test/Tech/tech.t' => [qw(0.04 2003/06/16), 'revised 0.03'],
     't/Test/Tech/tech0.d' => [qw(0.02 2003/06/13), 'unchanged'],
-    't/Test/Tech/tech0.t' => [qw(0.02 2003/06/13), 'unchanged'],
+    't/Test/Tech/tech0.t' => [qw(0.03 2003/06/16), 'revised 0.02'],
     't/Test/Tech/tech2.txt' => [qw(0.01 2003/06/12), 'unchanged'],
-    't/Test/Tech/tech3.txt' => [qw(0.01 2003/06/12), 'unchanged'],
+    't/Test/Tech/tech3.txt' => [qw(0.02 2003/06/16), 'revised 0.01'],
+    't/Test/Tech/tech4.txt' => [qw(0.03 2003/06/16), 'new'],
+    't/Test/Tech/tech5.txt' => [qw(0.03 2003/06/16), 'new'],
 
 );
 
@@ -52,11 +54,11 @@ use vars qw(%INVENTORY);
 
  Test::Tech - Extends the Test program module
 
- Revision: A
+ Revision: C
 
- Version: 0.02
+ Version: 0.03
 
- Date: 2003/06/15
+ Date: 2003/06/16
 
  Prepared for: General Public 
 
@@ -133,7 +135,7 @@ The dependency of the program modules in the US DOD STD2167A bundle is as follow
 
 =head2 1.3 Document overview.
 
-This document releases Test::Tech version 0.02
+This document releases Test::Tech version 0.03
 providing description of the inventory, installation
 instructions and other information necessary to
 utilize and track this release.
@@ -151,8 +153,8 @@ system file specification.
 This document releases the file found
 at the following repository:
 
-   http://www.softwarediamonds/packages/Test-Tech-0.02
-   http://www.perl.com/CPAN-local/authors/id/S/SO/SOFTDIA/Test-Tech-0.02
+   http://www.softwarediamonds/packages/Test-Tech-0.03
+   http://www.perl.com/CPAN-local/authors/id/S/SO/SOFTDIA/Test-Tech-0.03
 
 
 =head2 3.1.2 Copyright.
@@ -213,21 +215,86 @@ consists of the following files:
 
  file                                                         version date       comment
  ------------------------------------------------------------ ------- ---------- ------------------------
- lib/Docs/Site_SVD/Test_Tech.pm                               0.02    2003/06/15 revised 0.01
- MANIFEST                                                     0.02    2003/06/15 generated, replaces 0.01
- Makefile.PL                                                  0.02    2003/06/15 generated, replaces 0.01
- README                                                       0.02    2003/06/15 generated, replaces 0.01
- lib/Test/Tech.pm                                             1.04    2003/06/15 revised 1.03
- t/Test/Tech/tech.t                                           0.03    2003/06/15 revised 0.02
+ lib/Docs/Site_SVD/Test_Tech.pm                               0.03    2003/06/16 revised 0.02
+ MANIFEST                                                     0.03    2003/06/16 generated, replaces 0.02
+ Makefile.PL                                                  0.03    2003/06/16 generated, replaces 0.02
+ README                                                       0.03    2003/06/16 generated, replaces 0.02
+ lib/Test/Tech.pm                                             1.05    2003/06/16 revised 1.04
+ t/Test/Tech/tech.t                                           0.04    2003/06/16 revised 0.03
  t/Test/Tech/tech0.d                                          0.02    2003/06/13 unchanged
- t/Test/Tech/tech0.t                                          0.02    2003/06/13 unchanged
+ t/Test/Tech/tech0.t                                          0.03    2003/06/16 revised 0.02
  t/Test/Tech/tech2.txt                                        0.01    2003/06/12 unchanged
- t/Test/Tech/tech3.txt                                        0.01    2003/06/12 unchanged
+ t/Test/Tech/tech3.txt                                        0.02    2003/06/16 revised 0.01
+ t/Test/Tech/tech4.txt                                        0.03    2003/06/16 new
+ t/Test/Tech/tech5.txt                                        0.03    2003/06/16 new
 
 
 =head2 3.3 Changes
 
-Fixed prototype for &Test::Tech::skip_rest Test::Tech line 84
+The &Data::Dumper::Dumper subroutine stringifies the iternal Perl
+variable. Different Perls keep the have different internal formats
+for numbers. Some keep them as binary numbers, while others as
+strings. The ones that keep them as strings may be well spec.
+In any case they have been let loose in the wild so the test 
+scripts that use Data::Dumper must deal with them.
+
+Added a probe to determine how a Perl stores its internal
+numbers and added code to the test script to adjust for 
+the difference in Perl
+
+~~~~~
+
+######
+# This is perl, v5.6.1 built for MSWin32-x86-multi-thread
+# (with 1 registered patch, see perl -V for more detail)
+#
+# Copyright 1987-2001, Larry Wall
+#
+# Binary build 631 provided by ActiveState Tool Corp. http://www.ActiveState.com
+# Built 17:16:22 Jan  2 2002
+#
+#
+# Perl may be copied only under the terms of either the Artistic License or the
+# GNU General Public License, which may be found in the Perl 5 source kit.
+#
+# Complete documentation for Perl, including FAQ lists, should be found on
+# this system using `man perl' or `perldoc perl'.  If you have access to the
+# Internet, point your browser at http://www.perl.com/, the Perl Home Page.
+#
+# ~~~~~~~
+#
+# Wall, Christiansen and Orwant on Perl internal storage
+#
+# Page 351 of Programming Perl, Third Addition, Overloadable Operators
+# quote:
+# 
+# Conversion operators: "", 0+, bool
+#   These three keys let you provide behaviors for Perl's automatic conversions
+#   to strings, numbers, and Boolean values, respectively.
+# 
+# ~~~~~~~
+#
+# Internal Storage of Perls that are in the wild
+#
+#   string - Perl v5.6.1 MSWin32-x86-multi-thread, ActiveState build 631, binary
+#   number - Perl version 5.008 for solaris  
+#
+#   Perls in the wild with internal storage of string may be mutants that need to 
+#   be hunted down killed.
+#
+
+########
+# Probe Perl for internal storage method
+#
+my $probe = 3;
+my $actual = Dumper([0+$probe]);
+my $internal_storage = 'undetermine';
+if( $actual eq Dumper([5]) ) {
+    $internal_storage = 'number';
+}
+elsif ( $actual eq Dumper(['3']) ) {
+    $internal_storage = 'string';
+}
 
 =head2 3.4 Adaptation data.
 
@@ -262,8 +329,8 @@ Follow the instructions for the the chosen installation software.
 
 The distribution file is at the following respositories:
 
-   http://www.softwarediamonds/packages/Test-Tech-0.02
-   http://www.perl.com/CPAN-local/authors/id/S/SO/SOFTDIA/Test-Tech-0.02
+   http://www.softwarediamonds/packages/Test-Tech-0.03
+   http://www.perl.com/CPAN-local/authors/id/S/SO/SOFTDIA/Test-Tech-0.03
 
 
 =head2 3.6.1 Installation support.
@@ -370,13 +437,13 @@ __DATA__
 
 
 DISTNAME: Test-Tech^
-VERSION : 0.02^
+VERSION : 0.03^
 REPOSITORY_DIR: packages^
 FREEZE: 1^
 
 PREVIOUS_DISTNAME:  ^
-PREVIOUS_RELEASE: 0.01^
-REVISION: A^
+PREVIOUS_RELEASE: 0.02^
+REVISION: C^
 AUTHOR  : SoftwareDiamonds.com E<lt>support@SoftwareDiamonds.comE<gt>^
 
 ABSTRACT: 
@@ -415,9 +482,71 @@ PREREQ_PM: 'Test::TestUtil' => 0^
 TESTS: t/Test/Tech/tech.t^
 EXE_FILES:  ^
 
-CHANGES: 
-Fixed prototype for &Test::Tech::skip_rest Test::Tech line 84
+CHANGES:
+The &Data::Dumper::Dumper subroutine stringifies the iternal Perl
+variable. Different Perls keep the have different internal formats
+for numbers. Some keep them as binary numbers, while others as
+strings. The ones that keep them as strings may be well spec.
+In any case they have been let loose in the wild so the test 
+scripts that use Data::Dumper must deal with them.
 
+Added a probe to determine how a Perl stores its internal
+numbers and added code to the test script to adjust for 
+the difference in Perl
+
+~~~~~
+
+######
+# This is perl, v5.6.1 built for MSWin32-x86-multi-thread
+# (with 1 registered patch, see perl -V for more detail)
+#
+# Copyright 1987-2001, Larry Wall
+#
+# Binary build 631 provided by ActiveState Tool Corp. http://www.ActiveState.com
+# Built 17:16:22 Jan  2 2002
+#
+#
+# Perl may be copied only under the terms of either the Artistic License or the
+# GNU General Public License, which may be found in the Perl 5 source kit.
+#
+# Complete documentation for Perl, including FAQ lists, should be found on
+# this system using `man perl' or `perldoc perl'.  If you have access to the
+# Internet, point your browser at http://www.perl.com/, the Perl Home Page.
+#
+# ~~~~~~~
+#
+# Wall, Christiansen and Orwant on Perl internal storage
+#
+# Page 351 of Programming Perl, Third Addition, Overloadable Operators
+# quote:
+# 
+# Conversion operators: "", 0+, bool
+#   These three keys let you provide behaviors for Perl's automatic conversions
+#   to strings, numbers, and Boolean values, respectively.
+# 
+# ~~~~~~~
+#
+# Internal Storage of Perls that are in the wild
+#
+#   string - Perl v5.6.1 MSWin32-x86-multi-thread, ActiveState build 631, binary
+#   number - Perl version 5.008 for solaris  
+#
+#   Perls in the wild with internal storage of string may be mutants that need to 
+#   be hunted down killed.
+#
+
+########
+# Probe Perl for internal storage method
+#
+my $probe = 3;
+my $actual = Dumper([0+$probe]);
+my $internal_storage = 'undetermine';
+if( $actual eq Dumper([5]) ) {
+    $internal_storage = 'number';
+}
+elsif ( $actual eq Dumper(['3']) ) {
+    $internal_storage = 'string';
+}
 ^
 
 CAPABILITIES:
